@@ -61,8 +61,9 @@ MC14,MC15,MC16,MC17,MC18,MC19,MC20,MC21,MC22,MC23,MC24,MC25
     double precision,dimension(nb1,nb1)::vcjm
     double precision,dimension(nodes_number,nb1)::fraili
     double precision::SX,xMC ! for random generation
-    double precision,dimension(25000)::MC ! for Monte-carlo pre-generated points
-    integer::m     
+    double precision,dimension(:),allocatable::MC ! for Monte-carlo pre-generated points
+    integer::m
+    allocate(MC(25000))
             npp = np
         eps_s = 1.d-7
     !    print*,'debut funcpa'
@@ -435,9 +436,9 @@ MC14,MC15,MC16,MC17,MC18,MC19,MC20,MC21,MC22,MC23,MC24,MC25
                             nmes_o(ig) = nmescur
                         end if
                     end do
-				else
+                else
                     nmes_o(ig) = nmescur
-				end if
+                end if
     ! add TwoPart
     if(TwoPart.eq.1) then
         if(nmescurB.gt.0) then
@@ -513,7 +514,7 @@ MC14,MC15,MC16,MC17,MC18,MC19,MC20,MC21,MC22,MC23,MC24,MC25
         end do
     end if     
 
-if(nmescur.gt.0) then	
+if(nmescur.gt.0) then
             varcov_marg((it+1):(it+nmescur),1:nmescur) =Matmul( MATMUL(ziy((it+1):(it+nmescur),1:nby), &
                     MATMUL(Ut(1:nby,1:nby),Utt(1:nby,1:nby))),transpose(ziy((it+1):(it+nmescur),1:nby)))+ &
                     mat_sigma
@@ -598,7 +599,7 @@ if(nmescur.gt.0) then
             xea = 0.d0
 else
     mu = 0.d0
-	        do k=1,nb1
+    do k=1,nb1
         Z1 (:,k)=0.d0
             end do 
 end if
@@ -977,6 +978,7 @@ if(nmescur.eq.(-1)) then ! this is for the case where we have no repeated measur
         end if
     !Ad:
         123     continue    
+        deallocate(MC)
         return
     
     
