@@ -47,7 +47,7 @@ subroutine joint_competing(controls,nobsEvent,k0,&
     ni,constraintfrail,cptEvent,ResMartingaleEvent,frailtyEstimates, &
     linearpred,linearpreddc,linearpredM,linearpreddc2,ziOut1,ziOutdc,ziOutmeta, &
     time,timedc,timeM,ghNodes0,ghWeights0,tolerance0)
-
+    
     !use parametersjcompeting
     !use residusMjcompeting
     !use comonjcompeting
@@ -134,19 +134,22 @@ subroutine joint_competing(controls,nobsEvent,k0,&
     double precision,dimension(mtEvent(2),3)::lam2Out
     double precision,dimension(mt1Event(2))::xSu2
     double precision,dimension(mt1Event(2),3)::su2Out
-
     double precision,dimension(mtEvent(3))::x3Out, x4Out
-    double precision,dimension(mtEvent(3),3)::lam3Out, lam4Out
-    double precision,dimension(mt1Event(3))::xSu3, xSu4
+    double precision,dimension(mtEvent(3))::x4Out2
+    double precision,dimension(mtEvent(3),3)::lam3Out, lam4Out 
+    double precision,dimension(mtEvent(3),3)::lam4Out2
+    double precision,dimension(mt1Event(3))::xSu3, xSu4 
+    double precision,dimension(mt1Event(3))::xSu42
     double precision,dimension(mt1Event(3),3)::su3Out, su4Out
-
+    double precision,dimension(mt1Event(3),3)::su4Out2
     integer::ni
     integer,dimension(4),intent(out)::cptEvent
+    integer,dimension(4)::cptEvent2
     !    cptEvent=c(cpt,cpt_dc,cptmeta,cpt_dc2)
     !        counts of events of each type
-    double precision,dimension(nobsEvent(2),3)::ResMartingaleEvent
+    double precision,dimension(nobsEvent(2),3)::ResMartingaleEvent,ResMartingaleEvent2
     !    ResMartingaleEvent=c(Res_martingale,Res_martingaledc,Res_martingale2,Res_martingaledc2)
-    double precision,dimension(nobsEvent(2),5)::frailtyEstimates
+    double precision,dimension(nobsEvent(2),5)::frailtyEstimates,frailtyEstimates2
     !    frailtyEstimates=c(frailtypred,frailtypred2,frailtyvar,frailtyvar2,frailtyCorr)
     
     double precision,dimension(nobsEvent(1))::linearpred
@@ -155,7 +158,7 @@ subroutine joint_competing(controls,nobsEvent,k0,&
 
     double precision,dimension(controls(8)+6)::ziOut1,ziOutdc,ziOutmeta
     double precision,dimension(controls(7)+1)::time,timedc,timeM
-
+    double precision,dimension(controls(7)+1)::time2,timedc2,timeM2
     double precision,dimension(controls(11))::ghNodes0, ghWeights0
     double precision,dimension(3)::tolerance0
 
@@ -164,12 +167,12 @@ subroutine joint_competing(controls,nobsEvent,k0,&
     ! Other Variables
     integer::maxit0,maxit00,mt11,mt12,mt13,mt14,nsujetmeta0,ag0,initialize,&
     event2_ind0,terminal2_ind0
-    integer::nbIntervEvent,nz0
+    integer::nz0
     integer::nsujet0,ng0,nva10,nva20,nva30,nva40,mt1,mt2,mt3,mt4,irep
     integer::equidistant,equidistant0
     integer::ss,sss
     double precision,dimension(:),allocatable::b01,b02,b03,b04!,b02joint
-    integer::np1,np2,np3,np4,np2joint
+    integer::np1,np2,np3,np4
     double precision,dimension(4)::shape_weib,scale_weib    
     integer::noVar1,noVar2,noVar3,noVar4
     integer::cpt,cptmeta,cpt_dc,cpt_dc2,ier
@@ -183,45 +186,58 @@ subroutine joint_competing(controls,nobsEvent,k0,&
     double precision::ca,cb,dd
     double precision,external::funcpajcompetingWeib,funcpajcompetingsplines
     !cpm
-    integer::indd,ent,entdc,entmeta,typeof0,nzsha
-    double precision::temp,kappa1    
+    integer::typeof0 
     integer::nbinterv0
     !predictor
     double precision,dimension(nobsEvent(2))::Res_martingale,Res_martingaledc,Res_martingale2,&
     frailtypred,frailtypred2,frailtyvar,frailtyvar2,frailtyCorr
     double precision,external::funcpamultires
-    double precision,dimension(1,nbvar(1))::coefBeta
-    double precision,dimension(1,nbvar(2))::coefBetadc    
-    double precision,dimension(1,nbvar(3))::coefBetaM        
-    !double precision,dimension(1,nbvar(4))::coefBetadc2        
-    double precision,dimension(1,nobsEvent(1))::XBeta
-    double precision,dimension(1,nobsEvent(2))::XBetadc!, XBetadc2
-    double precision,dimension(1,nobsEvent(3))::XBetaM
     double precision,dimension(:,:),allocatable::ve1,ve2,ve3,ve4
+    !double precision,dimension(1,nbvar(1))::coefBeta
+    !double precision,dimension(1,nbvar(2))::coefBetadc    
+    !double precision,dimension(1,nbvar(3))::coefBetaM        
+    !double precision,dimension(1,nbvar(4))::coefBetadc2        
+    !double precision,dimension(1,nobsEvent(1))::XBeta
+    !double precision,dimension(1,nobsEvent(2))::XBetadc!, XBetadc2
+    !double precision,dimension(1,nobsEvent(3))::XBetaM
     !-------- Parametres shared
-    double precision::ddls
-    double precision,dimension(:),allocatable::str00
-    integer::cpts
-    double precision,dimension(:,:),allocatable::H_hess0,HIH0
-    double precision,dimension(2)::LCVs,shapeweibs,scaleweibs,k0s
+    !double precision::ddls
+    !double precision,dimension(:),allocatable::str00
+    !integer::cpts
+    !double precision,dimension(:,:),allocatable::H_hess0,HIH0
+    !double precision,dimension(2)::LCVs,shapeweibs,scaleweibs,k0s
     !double precision,dimension(:),allocatable::x1Outs,x2Outs
-    double precision,dimension(:,:),allocatable::xTOuts !en plus
+    !double precision,dimension(:,:),allocatable::xTOuts !en plus
     !double precision,dimension(:,:),allocatable::lamOuts,lam2Outs
-    double precision,dimension(:,:,:),allocatable::lamTOuts !en plus
+    !double precision,dimension(:,:,:),allocatable::lamTOuts !en plus
     !double precision,dimension(100,3)::suOuts,su2Outs
-    double precision,dimension(100,3,1)::suTOuts !en plus
+    !double precision,dimension(100,3,1)::suTOuts !en plus
     !double precision,dimension(100)::xSu1s,xSu2s
-    double precision,dimension(100,1)::xSuTs !en plus
-    double precision,dimension(:),allocatable::zis
-    double precision,dimension(nobsEvent(2))::Resmartingales,frailtypreds,frailtysds,frailtyvars
-    double precision,dimension(:),allocatable::linearpreds,martingaleCoxs,times
-    integer::timedepMul,nbinnerknots0Mul,qorder0Mul
-    integer,dimension(:),allocatable::filtretps0Mul
-    double precision,dimension(0:100,1)::BetaTpsMatMul
-    double precision,dimension(3)::EPS 
+    !double precision,dimension(100,1)::xSuTs !en plus
+    !double precision,dimension(:),allocatable::zis
+    !double precision,dimension(nobsEvent(2))::Resmartingales,frailtypreds,frailtysds,frailtyvars
+    !double precision,dimension(:),allocatable::linearpreds,martingaleCoxs,times
+    !integer::timedepMul,nbinnerknots0Mul,qorder0Mul
+    !integer,dimension(:),allocatable::filtretps0Mul
+    !double precision,dimension(0:100,1)::BetaTpsMatMul
+    !double precision,dimension(3)::EPS 
     integer::iter_kappas
     !End other variables
     !----------------------------------------------------------------------------
+
+    !dummy state;ent to remove 'unused arguments' compilation warnings
+    if(.false.) then 
+        x4Out2=x4Out
+        lam4Out2=lam4Out 
+        xSu42 = xSu4
+        su4Out2=su4Out 
+        cptEvent2 = cptEvent 
+        ResMartingaleEvent2 = ResMartingaleEvent
+        frailtyEstimates2 = frailtyEstimates 
+        time2 = time 
+        timedc2 = timedc 
+        timeM2 = timeM
+    end if 
     maxit0=controls(1)
     maxit00=controls(1)
     initialize = controls(2)
@@ -269,7 +285,7 @@ subroutine joint_competing(controls,nobsEvent,k0,&
     typeof = typeof0
     ier = 0
     istop = 0
-
+    iter_kappas = 0 
     constraintfrailty = constraintfrail
 
     !convergence criteria
@@ -279,7 +295,10 @@ subroutine joint_competing(controls,nobsEvent,k0,&
 
     !----------------------------------------------------------------------
     ! (2) Parameter Initialization
-
+    np1 = 0
+    np2 = 0 
+    np3 = 0 
+    np4 = 0
     select case(typeof)
         case(0) ! splines
             np1 = nz0 + 2 + nva10 + 1 
@@ -1200,13 +1219,23 @@ subroutine joint_competing(controls,nobsEvent,k0,&
         case(0)
             !call distanceJ_splines(nzloco,nzdc,nzmeta,b,mt1,mt2,mt3,x1Out,lamOut,suOut,x2Out,lam2Out,su2Out,&
             !x3Out,lam3Out,su3Out)
-            call distancessplinesV2(nzloco,zi,nzloco+3,np,b,H_hess,effet,mt1,x1Out,lamOut,suOut)
-            call distancessplinesV2(nzdc,zidc,nzdc+3,np-nzloco-2,b((nzloco+3):np),&
+            
+            !call distancessplinesV2(nzloco,zi,nzloco+3,np,b,H_hess,effet,mt1,x1Out,lamOut,suOut)
+            !call distancessplinesV2(nzdc,zidc,nzdc+3,np-nzloco-2,b((nzloco+3):np),&
+            !                        H_hess((nzloco+3):np,(nzloco+3):np),&
+            !                        effet,mt2,x2Out,lam2Out,su2Out)
+            !call distancessplinesV2(nzdc,zidc,nzdc+3,np-nzloco-nzdc-4,b((nzloco+nzdc+5):np),&
+            !                        H_hess((nzloco+nzdc+5):np,(nzloco+nzdc+5):np),&
+            !                        effet,mt3,x3Out,lam3Out,su3Out)
+
+            call distancessplinesV2(nzloco,zi,np,b(1:np),H_hess(1:np,1:np),effet,mt1,x1Out,lamOut,suOut)
+            call distancessplinesV2(nzdc,zidc,np-nzloco-2,b((nzloco+3):np),&
                                     H_hess((nzloco+3):np,(nzloco+3):np),&
                                     effet,mt2,x2Out,lam2Out,su2Out)
-            call distancessplinesV2(nzdc,zidc,nzdc+3,np-nzloco-nzdc-4,b((nzloco+nzdc+5):np),&
+            call distancessplinesV2(nzdc,zidc,np-nzloco-nzdc-4,b((nzloco+nzdc+5):np),&
                                     H_hess((nzloco+nzdc+5):np,(nzloco+nzdc+5):np),&
                                     effet,mt3,x3Out,lam3Out,su3Out)
+
         case(1)
             !Call distanceJ_cpm(b,nbintervR+nbintervDC+nbintervM,mt1,mt2,mt3,x1Out,lamOut,xSu1,suOut,x2Out, &
             !lam2Out,xSu2,su2Out,x3Out,lam3Out,xSu3,su3Out)
